/*
* Copyright (c) Visioglobe SAS. All rights reserved.
*
* This file is subject to the terms and conditions defined in
* file 'LICENSE.txt', which is part of this source code package.
*/

import UIKit
import VisioMoveEssential

class ContentMapViewController: UIViewController, VMELifeCycleListener {
    @IBOutlet var mapView: VMEMapView!
    @IBOutlet var placeColorLabel: UILabel!
    @IBOutlet var placeAllColorLabel: UILabel!
    @IBOutlet var placeAddLabel: UILabel!
    var mPlaceIDs: [AnyHashable] = []

    class func randomColor() -> UIColor? {
        let lRed = Int(arc4random() % 255)
        let lGreen = Int(arc4random() % 255)
        let lBlue = Int(arc4random() % 255)
        let lRandomColor = UIColor(red: CGFloat(Double(lRed) / 255.0), green: CGFloat(Double(lGreen) / 255.0), blue: CGFloat(Double(lBlue) / 255.0), alpha: 1.0)
        return lRandomColor
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        title = NSLocalizedString("ContentMapViewController.title", comment: "")
        placeColorLabel.text = NSLocalizedString("ContentMapViewController.placeColorLabel", comment: "")
        placeAllColorLabel.text = NSLocalizedString("ContentMapViewController.placeAllColorLabel", comment: "")
        placeAddLabel.text = NSLocalizedString("ContentMapViewController.placeAddLabel", comment: "")

        mPlaceIDs = ["B1-UL00-ID0034", "B1-UL00-ID0042", "B1-UL00-ID0038", "B1-UL00-ID0043", "busstation01", "lCatOnline"]

        mapView?.lifeCycleListener = self
        mapView?.loadMap()
        
        // IMPORTANT: Ensure the mapView starts below the navigation bar, otherwise
        // VisioMove Essential's search view button will be hidden.
        if responds(to: #selector(getter: UIViewController.edgesForExtendedLayout)) {
            edgesForExtendedLayout = []
        }
    }
    
    @IBAction func placeColorSwitchAction(_ sender: Any) {
        let lSwitch = sender as? UISwitch
        if lSwitch?.isOn == true {
            let lRandomColor = ContentMapViewController.randomColor()!
            for lPlaceID in mPlaceIDs {
                mapView?.setPlaceID((lPlaceID as? String)!, color: lRandomColor)
            }
        } else {
            for lPlaceID in mPlaceIDs {
                mapView?.resetPlaceIDColor((lPlaceID as? String)!)
            }
        }
        // Move the camera to look at the color change
        let lUpdate = VMECameraUpdate(builderBlock: { builder in
                builder?.targets = self.mPlaceIDs
            builder?.viewMode = VMEViewMode.floor
            builder?.heading = VMECameraHeading(forPlaceID: "B1")
        })!
        mapView?.animateCamera(lUpdate)
    }
    
    @IBAction func placeAllColorSwitchAction(_ sender: Any) {
        let lSwitch = sender as? UISwitch
        let lPlaceIDs = mapView?.queryAllPlaceIDs()
        if lSwitch?.isOn == true {
            let lRandomColor = ContentMapViewController.randomColor()
            var lPlaceToColor: [String : UIColor]? = [:]
            for lPlaceID in lPlaceIDs ?? [] {
                lPlaceToColor?[lPlaceID] = lRandomColor
            }
            mapView?.setPlaceColor(lPlaceToColor!)
        } else {
            mapView?.resetPlaceColor(lPlaceIDs!)
        }
    }
    
    @IBAction func placeAddSwitchAction(_ sender: Any) {
        let lSwitch = sender as? UISwitch
        let lCatOfflineMainBundle = "lCatOfflineMainBundle"
        let lCatMapBundle = "lCatMapBundle"
        let lCatOnline = "lCatOnline"

        if lSwitch?.isOn == true {
            var lPositions: [AnyHashable] = []

            // lCatMapBundle
            do {
                //var lScene = VMESceneContext.init(outside:())
                
                let lScene = VMESceneContext()
                //lScene.initOutside()
                
                let lPos = VMEPosition(latitude: 45.74094, longitude: 4.88483, altitude: 0.0, scene: lScene)
                lPositions.append(lPos)

                let lIconUrl = URL(string: "/media/map/visio_island_essentials/category_exhibition.png")
                let placeData = [
                    "name" : "Cat - Map bundle",
                    "description" : "<b>Map Bundle</b> <hr> The icon comes from the map bundle.",
                    "icon" : lIconUrl?.absoluteString as Any,
                    "categories" : ["2", "3", "99"]
                    ]
                
                mapView?.addPlaceID(
                    lCatMapBundle,
                    imageURL: lIconUrl,
                    data: placeData,
                    position: lPos!,
                    size: VMEPlaceSize(scale: 1.0),
                    anchorMode: VMEPlaceAnchorMode.bottomCenter,
                    altitudeMode: VMEPlaceAltitudeMode.relative,
                    displayMode: VMEPlaceDisplayMode.overlay,
                    orientation: VMEPlaceOrientation.placeOrientationFacing(),
                    visibilityRamp: VMEPlaceVisibilityRamp())
                mapView?.setPlaceID(lCatMapBundle, size: VMEPlaceSize(scale: 20.0), animated: true)
            }
            
            // lCatOfflineAsset
            do {
                let lPos = VMEPosition(latitude: 45.74131, longitude: 4.88216, altitude: 0.0, scene: VMESceneContext())
                lPositions.append(lPos)

                // Now that the minimum deployment target is iOS 8, it's no longer
                // possible to retrieve the path of an icon (they're packaged within
                // Assets.car).  Instead, we simply pass the icon name (excluding the
                // extension).
                let lIconUrl = URL(string: "marker_cat_curious")
                let placeData = [
                    "name" : "Cat - Main bundle",
                    "description" : "<b>Main bundle</b> <hr>  The icon comes from the application's main bundle",
                    "icon" : lIconUrl?.absoluteString as Any,
                    "categories" : ["2", "3", "99"]
                    ]
                
                mapView?.addPlaceID(
                    lCatOfflineMainBundle,
                    imageURL: lIconUrl,
                    data: placeData,
                    position: lPos!,
                    size: VMEPlaceSize(scale: 1.0),
                    anchorMode: VMEPlaceAnchorMode.bottomCenter,
                    altitudeMode: VMEPlaceAltitudeMode.relative,
                    displayMode: VMEPlaceDisplayMode.overlay,
                    orientation: VMEPlaceOrientation.placeOrientationFacing(),
                    visibilityRamp: VMEPlaceVisibilityRamp())
                    mapView?.setPlaceID(lCatOfflineMainBundle, size: VMEPlaceSize(scale: 20.0), animated: true)
            }
            
            // lCatOnline
            do {
                let lPos = VMEPosition(latitude: 45.74140, longitude: 4.88349, altitude: 0.0, scene: VMESceneContext())
                lPositions.append(lPos)

                let lIconUrl = URL(string: "https://i.pinimg.com/originals/5c/b9/18/5cb918952f184853961ea83597082f38.png")

                let placeData = [
                    "name" : "Cat - Online",
                    "description" : "https://en.wikipedia.org/wiki/Cat",
                    "icon" : lIconUrl?.absoluteString as Any,
                    "categories" : ["2", "3", "99"]
                ]
                
                mapView?.addPlaceID(lCatOnline,
                                    imageURL: lIconUrl,
                                    data: placeData,
                                    position: lPos!,
                                    size: VMEPlaceSize(scale: 1.0),
                                    anchorMode: VMEPlaceAnchorMode.bottomCenter,
                                    altitudeMode: VMEPlaceAltitudeMode.relative,
                                    displayMode: VMEPlaceDisplayMode.overlay,
                                    orientation: VMEPlaceOrientation.placeOrientationFacing(),
                                    visibilityRamp: VMEPlaceVisibilityRamp())
                mapView?.setPlaceID(lCatOnline, size: VMEPlaceSize(scale: 20.0), animated: true)
                
            }
            let lPadding: CGFloat = 50
            let lCameraUpdate = VMECameraUpdate(builderBlock: { builder in
                    builder?.targets = lPositions
                    builder?.paddingTop = lPadding
                    builder?.paddingBottom = lPadding
                    builder?.paddingLeft = lPadding
                    builder?.paddingRight = lPadding
                })
            mapView?.animateCamera(lCameraUpdate!)
        } else {
            mapView?.removePlaceID(lCatMapBundle)
            mapView?.removePlaceID(lCatOfflineMainBundle)
            mapView?.removePlaceID(lCatOnline)
        }
    }
    
    
    /// In this example we read the place data from a local json file.  In reality,
    /// the data would most likely be downloaded from a remote webservice to ensure
    /// the most up to date information.
    func mapDidInitializeEngine(_ mapView: VMEMapView?) {
        
        let path = Bundle.main.path(forResource: "visio_island_cms_update", ofType: "json")
        let returnedData = FileManager.default.contents(atPath: path ?? "")
        
        if NSClassFromString("NSJSONSerialization") != nil {
            var object: Any? = nil
            do {
                object = try JSONSerialization.jsonObject(with: returnedData!, options: [])
            } catch {
                print(error)
                return
            }
            if (object is [AnyHashable : Any]) {
                let results = object as! NSDictionary
                self.mapView?.updatePlaceData((results.value(forKeyPath: "locale.en") as? [AnyHashable : Any])!)
            }
        }
    }
    
    func mapDidLoad(_ mapView: VMEMapView?) {
        print("Map did load")
        
        // customData
        mapView?.fetchCustomData(successBlock: {
            let lCustomData = mapView?.getCustomData()
            let lCustomDataForPlaceID =  lCustomData?["parking01"]
            print("ContentDemoFragment - Custom data = \(lCustomData as Any)")
            print("ContentDemoFragment - Parking 01 custom data = \(lCustomDataForPlaceID as Any)")
        }, andErrorBlock: { err in
            print(err as Any)
        })
        
    }
}
