/*
* Copyright (c) Visioglobe SAS. All rights reserved.
*
* This file is subject to the terms and conditions defined in
* file 'LICENSE.txt', which is part of this source code package.
*/

import Foundation
import UIKit
import VisioMoveEssential

/**
* A simple NSObject that holds the details about the demo that are used by the UITableDataSource.
*/

@objcMembers class DemoDetails: NSObject {
    //public var viewController: UIViewController;
    
    /**
    * The resource id of the title of the demo.
    */
    public var mTitle: String?;
    
    /**
    * The resources id of the description of the demo.
    */
    public var mDescription: String?;
    
    /**
    * The demo UIViewController 's class.
    */
    private var mClass: UIViewController.Type;
    
    private var mViewController: UIViewController?;
    
    init(title: String?, description: String?, class c: UIViewController.Type) {
        mTitle = title
        mDescription = description
        mClass = c
        super.init()
    }
    
    @objc func viewController() -> UIViewController? {
        if (self.mViewController == nil) {
            let controller = NSStringFromClass(mClass.self)
            if Bundle.main.path(forResource: controller, ofType: "nib") != nil {
                //NSLog("test: %@ %@", mClass, mClass.self);
                //var clz: NSObject.Type = mClass as! NSObject.Type
                //clz.init(nibName: controller, bundle: nil)
                //UIViewController.init(nibName: controller, bundle: nil)
                mViewController = mClass.init(nibName: controller, bundle: nil)
            } else {
                let swiftControllerArray = controller.components(separatedBy: ".")
                if swiftControllerArray.count > 1 {
                    let swiftController = swiftControllerArray[1]
                    if Bundle.main.path(forResource: swiftController, ofType: "nib") != nil {
                        mViewController = mClass.init(nibName: swiftController, bundle: nil)
                    } else {
                        NSLog("No bundle found with name: %@", swiftController)
                    }
                } else {
                      NSLog("No bundle found in array: %@", swiftControllerArray)
                }
            }
        }
        return self.mViewController;
    }
    
}

