/*
* Copyright (c) Visioglobe SAS. All rights reserved.
*
* This file is subject to the terms and conditions defined in
* file 'LICENSE.txt', which is part of this source code package.
*/

import UIKit
import VisioMoveEssential

/// Demonstrates how it's possible to open the search view and receive the result.

class SearchMapViewController: UIViewController, VMESearchViewCallback {
    @IBOutlet var mapView: VMEMapView!
    @IBOutlet var searchButton: UIButton!
    @IBOutlet var gotoPlaceButton: UIButton!
    @IBOutlet var selectedPlaceLabel: UILabel!

    private var selectedPlaceID: String?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        title = NSLocalizedString("SearchMapViewController.title", comment: "")
        searchButton.setTitle(NSLocalizedString("SearchMapViewController.searchButton", comment: ""), for: .normal)
        selectedPlaceLabel.text = ""
        gotoPlaceButton.isHidden = true
        gotoPlaceButton.setTitle(NSLocalizedString("SearchMapViewController.gotoButton", comment: ""), for: .normal)

        mapView?.loadMap()

        // IMPORTANT: Ensure the mapView starts below the navigation bar, otherwise
        // VisioMove Essential's search view button will be hidden.
        if responds(to: #selector(getter: UIViewController.edgesForExtendedLayout)) {
            edgesForExtendedLayout = []
        }
    }
    
    @IBAction func openSearchView(_ sender: Any) {
        mapView?.showSearch(withTitle: NSLocalizedString("SearchMapViewController.title", comment: ""), callback: self)
        selectedPlaceLabel.text = ""
        selectedPlaceID = nil
        gotoPlaceButton.isHidden = true
    }

    @IBAction func gotoPlace(_ sender: Any) {
        mapView?.showPlaceInfo(selectedPlaceID!)
    }
    
    // MARK: - VMESearchViewCallback
    func search(_ mapView: VMEMapView?, didSelectPlaceID placeID: String?) {
        selectedPlaceID = placeID
        selectedPlaceLabel.text = "\(selectedPlaceID ?? "Not found")"
        gotoPlaceButton.isHidden = false
    }

    func searchViewDidCancel(_ mapView: VMEMapView?) {
        selectedPlaceLabel.text = NSLocalizedString("SearchMapViewController.nothingSelected", comment: "")
    }
}
